@@ -1,4 +1,4 @@
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 void
 on_file_new_activate                   (GtkMenuItem     *menuitem,
@@ -30,14 +30,12 @@ void
 on_help_about_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_choose_template_OK_clicked          (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_tv_sheets_cursor_changed            (GtkTreeView     *treeview,
                                         gpointer         user_data);
 
+void on_choose_template_OK_clicked(GtkTreeView *tv, gpointer user_data);
+
 void on_choose_file_open(GtkButton *button, gpointer user_data);
 void on_choose_file_copy_last_year(GtkButton *button, gpointer user_data);
 void on_choose_file_save(GtkButton *button, gpointer user_data);
@@ -52,16 +50,6 @@ on_file_close_activate                 (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
-gboolean
-on_export_druid_cancel                 (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-void
-on_export_druid_finish                 (GnomeDruidPage  *gnomedruidpage,
-                                        GtkWidget       *widget,
-                                        gpointer         user_data);
-
 gboolean
 on_taxbird_configure                   (GtkWidget       *widget,
                                         GdkEventConfigure *event,
