@@ -19,7 +19,7 @@
 #ifndef TAXBIRD_DIALOG_H
 #define TAXBIRD_DIALOG_H
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 /* display a common error dialog with the given message (in modal mode) */
 void taxbird_dialog_error(GtkWidget *parent, const char *message);
