@@ -40,7 +40,7 @@ unsigned int forms_num = 0;
  */
 SCM
 taxbird_form_register(SCM name, SCM get_sheet_tree, SCM get_sheet,
-		      SCM dataset_read, SCM dataset_write, 
+		      SCM dataset_read, SCM dataset_write, SCM dataset_recalc,
 		      SCM dataset_export, SCM dataset_create)
 {
   struct form **new_f = realloc(forms, sizeof(struct form *) * (forms_num + 1));
@@ -65,6 +65,7 @@ taxbird_form_register(SCM name, SCM get_sheet_tree, SCM get_sheet,
 
   scm_gc_protect_object(forms[forms_num]->dataset_read = dataset_read);
   scm_gc_protect_object(forms[forms_num]->dataset_write = dataset_write);
+  scm_gc_protect_object(forms[forms_num]->dataset_recalc = dataset_recalc);
   scm_gc_protect_object(forms[forms_num]->dataset_export = dataset_export);
   scm_gc_protect_object(forms[forms_num]->dataset_create = dataset_create);
 
